@@ -1,5 +1,8 @@
+from __future__ import unicode_literals
+
 from django import template
 from courseaffils.lib import get_public_name
+from courseaffils.views import get_courses_for_instructor
 
 register = template.Library()
 
@@ -40,21 +43,24 @@ Syntax: %s """ + parts + """ as <varname>"""
         words = words[:-2]
 
         if _as != 'as':
-            raise template.TemplateSyntaxError, \
-                cls.error_msg() % (token.contents, tag_name)
+            raise (
+                template.TemplateSyntaxError,
+                cls.error_msg() % (token.contents, tag_name))
 
         words = chunk(words)
         if len(words) != len(cls.noun_for):
-            raise template.TemplateSyntaxError, \
-                cls.error_msg() % (token.contents, tag_name)
+            raise (
+                template.TemplateSyntaxError,
+                cls.error_msg() % (token.contents, tag_name))
 
         kw = {}
         for phrase in words:
             preposition, noun = phrase
             if preposition not in cls.noun_for \
                     or cls.noun_for[preposition] in kw:
-                raise template.TemplateSyntaxError, \
-                    cls.error_msg() % (token.contents, tag_name)
+                raise (
+                    template.TemplateSyntaxError,
+                    cls.error_msg() % (token.contents, tag_name))
             kw[cls.noun_for[preposition]] = noun
 
         return cls(varname, **kw)
@@ -84,13 +90,18 @@ class GetCourses(TemplateTagNode):
         TemplateTagNode.__init__(self, varname, user=user)
 
     def execute_query(self, user):
-        #import here, because it doesn't work above
-        from courseaffils.models import Course
-        return Course.objects.filter(group__in=user.groups.all())
+        from courseaffils.views import get_courses_for_user
+        return get_courses_for_user(user)
+
 
 register.tag('get_courses', GetCourses.process_tag)
 
 
+@register.simple_tag
+def get_instructor_courses(user):
+    return get_courses_for_instructor(user)
+
+
 class CourseRole(TemplateTagNode):
     noun_for = {"for": "user", "in": "course"}
 
@@ -100,12 +111,13 @@ class CourseRole(TemplateTagNode):
     def execute_query(self, user, course):
         if not course:
             return "no-course"
-        if not user in course.members:
-            return "non-member"
-        elif user in course.faculty:
+        elif course.is_true_faculty(user):
             return "instructor"
-        else:
+        elif course.is_true_member(user):
             return "student"
+        else:
+            return "non-member"
+
 
 register.tag('course_role', CourseRole.process_tag)
 
@@ -131,10 +143,6 @@ class PublicName(TemplateTagNode):
             return cls(words[2], user=words[2])
         else:
             return cls(words[2], user=words[2], truncate=int(words[4]))
-register.tag('public_name', PublicName.process_tag)
 
-if not hasattr(template.defaulttags, 'csrf_token'):
-    ### for Django1.1.2- compatibility
-    @register.tag(name="csrf_token")
-    def csrf_token(parser, token):
-        return template.Node()
+
+register.tag('public_name', PublicName.process_tag)
