@@ -1,15 +1,18 @@
-from django.test import TestCase
-from courseaffils.middleware import is_anonymous_path
-from courseaffils.middleware import already_selected_course
+from __future__ import unicode_literals
+
 from courseaffils.middleware import CourseManagerMiddleware
-from django.contrib.auth.models import Group, User
+from courseaffils.middleware import already_selected_course
+from courseaffils.middleware import is_anonymous_path
 from courseaffils.models import Course
+from django.contrib.auth.models import Group, User
+from django.http.response import Http404
+from django.test import TestCase
 
 
 class StubRequest(object):
     COOKIES = dict()
     GET = dict()
-    REQUEST = dict()
+    POST = dict()
     environ = dict()
 
     def __init__(self, c):
@@ -94,11 +97,17 @@ class MiddlewareSimpleTest(TestCase):
 
         r = StubRequest(self.c)
         r.user = self.student
-        r.REQUEST['set_course'] = 'studentgroup'
+        r.POST['set_course'] = 'studentgroup'
         assert c.process_request(r) is None
 
         r = StubRequest(self.c)
         r.user = self.student
-        r.REQUEST['set_course'] = 'studentgroup'
+        r.POST['set_course'] = 'foobarbaz'
+        with self.assertRaises(Http404):
+            c.process_request(r)
+
+        r = StubRequest(self.c)
+        r.user = self.student
+        r.POST['set_course'] = 'studentgroup'
         r.GET['next'] = "/foo"
         assert c.process_request(r) is not None
